@@ -7,19 +7,22 @@
  *
  * Copyright (C) Open-Xchange Inc., 2006-2011
  */
-define('oxguard/contacts/register_contacts', ['io.ox/core/extensions', 'oxguard/pgp/publickeys', 
-                           'css!oxguard/style.css'],
-                           function (ext, pubkeys) {
-    
+define('oxguard/contacts/register_contacts', [
+    'io.ox/core/extensions',
+    'oxguard/pgp/publickeys',
+    'less!oxguard/style'
+], function (ext, pubkeys) {
+
     ext.point('io.ox/contacts/detail').extend({
         id: 'pgppublic',
         index: 'last',
         draw: function (baton) {
+            //FIXME: this completely disables the point for apps other than settings and contacts (like mail called from sidepanel)
+            if (!(baton.app && baton.app.cid)) return;
+
             var list = (baton.data.email1 ? baton.data.email1 : '') + ',' + (baton.data.email2 ? baton.data.email2 : '') + ',' + (baton.data.email3 ? baton.data.email3 : '');
             var newfield = $('<fieldset class="block" data-block="pgp">');
-            $(this).find('.clearfix').append(newfield.append(pubkeys.listPublic(baton.app.id, list)));
+            $(this).find('.clearfix').append(newfield.append(pubkeys.listPublic(baton.app.cid, list)));
         }
-        
     });
-    
-});
\ No newline at end of file
+});
