@@ -7,10 +7,10 @@
  *
  * Copyright (C) Open-Xchange Inc., 2006-2011
  */
-define('oxguard/core/og_http', [],
-                           function () {
+define('oxguard/core/og_http', [
+], function () {
     'use strict';
-    
+
     function doPost (url, params, data) {
         var def = $.Deferred();
         if (data === null || data === undefined) data = {};
@@ -29,22 +29,21 @@ define('oxguard/core/og_http', [],
             });
             def.reject(r);
         });
-        
         return (def);
     }
-    
+
     // Look for passwords in outgoing data.  If able, encrypt
     function post (url, params, data) {
         var def = $.Deferred();
         require (['oxguard/crypto/encr'], function (encr) {
-            if (window.oxguarddata.pubkey !== undefined && data !== undefined) {
+            if (window.oxguarddata && window.oxguarddata.pubkey !== undefined && data !== undefined) {
                 if (data.password !== undefined) {
                     if (data.password !== '') {
                         var epass = encr.cryptPass(data.password);
                         if (epass !== null) {
                             data.e_password = epass;
                             delete data.password;
-                        } 
+                        }
                     }
                 }
                 if (data.ox_password !== undefined) {
@@ -85,10 +84,10 @@ define('oxguard/core/og_http', [],
         });
         return (def);
     }
-    
+
     function get (url, params) {
         var def = $.Deferred();
-        
+
         var t0 = _.now();
         $.get(url + params, function (rdata) {
             def.resolve(rdata);
@@ -104,13 +103,12 @@ define('oxguard/core/og_http', [],
             });
             def.reject(r);
         });
-        
+
         return (def);
     }
-    
+
     return {
-        post : post,
-        get : get
+        post: post,
+        get: get
     };
-    
-});
\ No newline at end of file
+});
