@@ -7,27 +7,40 @@
  *
  * Copyright (C) Open-Xchange Inc., 2006-2011
  */
-define('oxguard/core/passwords', ['gettext!oxguard/core/passwords'],
-                           function (gt) {
+define('oxguard/core/passwords', [
+    'gettext!oxguard'
+], function (gt) {
     'use strict';
-    
-    function passwordCompare (el1, el2) {
+
+    // Compare two el1 to el2 values whenever el1 changes.  If hint
+    // has value, then color and text if different
+    function passwordCompare (el1, el2, hint) {
         $(el1).on('input', function () {
             $(el1).removeClass('oxguard_badpass');
             if ($(el1).length >= 1) {
+                el2.removeClass('oxguard_warnpass').removeClass('oxguard_badpass').removeClass('oxguard_goodpass');  // remove color markup of the first password box
                 if ($(el1).val() !== $(el2).val()) {
                     $(el1).addClass('oxguard_badpass');
+                    if (hint !== undefined) {
+                        hint.removeClass('oxguard_hint_bad').removeClass('oxguard_hint_good').removeClass('oxguard_hint_warn');
+                        hint.addClass('oxguard_hint_bad').text(gt('Passwords not equal'));
+                    }
+                } else {
+                    if (hint !== undefined) {
+                        hint.text('');
+                    }
                 }
             }
         });
     }
-    
+
+    // Add event to check password strength of element
     function passwordCheck(element, hint) {
         $(element).on('input', function () {
             check.call(this, hint);
         });
     }
-    
+
     function check(hint) {
         var min = window.oxguarddata.settings.min_password_length;
         var len = window.oxguarddata.settings.password_length;
@@ -64,12 +77,10 @@ define('oxguard/core/passwords', ['gettext!oxguard/core/passwords'],
         if (hint !== undefined) {
             hint.addClass('oxguard_hint_warn').text(gt('Weak'));
         }
-        
     }
-    
+
     return {
-        passwordCheck : passwordCheck,
-        passwordCompare : passwordCompare
+        passwordCheck: passwordCheck,
+        passwordCompare: passwordCompare
     };
-    
-});
\ No newline at end of file
+});
