@@ -1,15 +1,18 @@
-define('oxguard/mail/maillist', ['io.ox/mail/common-extensions', 'io.ox/core/extensions'],
-       function (extensions, ext) {
+define('oxguard/mail/maillist', [
+    'io.ox/mail/common-extensions',
+    'io.ox/core/extensions'
+], function (extensions, ext) {
     'use strict';
-    
+
     var lockclass = 'icon-lock icon-2x fa fa-lock fa-2x oxguard_icon_fa';
+    var newlockclass = 'icon-lock icon-2x fa fa-lock encrypted';
     var initialized = false;
-   
+
     // Changed selection.  Null out the guard current data
     function change () {
         window.oxguarddata.current = null;
     }
-        
+
     // To initialize listview.  Setup here
     function listViewInit() {
         require (['io.ox/mail/main'], function (main) {
@@ -17,13 +20,11 @@ define('oxguard/mail/maillist', ['io.ox/mail/common-extensions', 'io.ox/core/ext
             app.listView.on('selection:change', change);
         });
     }
-    
-    
+
     // Disable default paper clip, as all oxguard emails have attachments.  Will call manually.
     ext.point('io.ox/mail/listview/item/default/row2').disable('paper-clip');
     ext.point('io.ox/mail/listview/item/small/col4').disable('paper-clip');
-    
-    
+
     ext.point('io.ox/mail/listview/item/default/row2').extend({
         id: 'OGpaper-clip',
         index: 300,
@@ -31,8 +32,8 @@ define('oxguard/mail/maillist', ['io.ox/mail/common-extensions', 'io.ox/core/ext
             addLock.call(this, baton);
         }
     });
-    
-    // Extension point for List view, change in 7.6.1   
+
+    // Extension point for List view, change in 7.6.1
     if (ox.serverConfig.version.indexOf('7.6.0') === 0) {
         ext.point('io.ox/mail/listview/item/small/col4').extend({
             id: 'OGpaper-clipSm',
@@ -52,8 +53,6 @@ define('oxguard/mail/maillist', ['io.ox/mail/common-extensions', 'io.ox/core/ext
         });
     }
 
-
-    
     // Check if OxGuard email, and if so, add lock icon.  Add paperclip if applicable
     function addLock(baton) {
         try {
@@ -77,9 +76,13 @@ define('oxguard/mail/maillist', ['io.ox/mail/common-extensions', 'io.ox/core/ext
             /// PGP Components
             // Check if decoded
             if (baton.model.get('PGPDecoded') === true) {
-                this.append($('<i class="' + lockclass + '" aria-hidden="true">'));
+                if (baton.model.get('attachments')[0].pgpFormat === 'pgpinline') {
+                    this.append($('<i class="' + newlockclass + '" aria-hidden="true">'));
+                }
                 if (baton.model.get('attachment') === true) {
                     extensions.paperClip.call(this, baton);
+                } else {
+                    $(this).find('.fa-paperclip').hide();  // remove if already added
                 }
                 return;
             }
@@ -87,14 +90,10 @@ define('oxguard/mail/maillist', ['io.ox/mail/common-extensions', 'io.ox/core/ext
             for (var i = 0; i < attachments.length; i++) {// check for attachments
                 try {
                     if (attachments[i].content_type !== null) {
-                        if (attachments[i].content_type.indexOf('pgp-encrypted') > 0) {
-                            this.append($('<i class="' + lockclass + '" aria-hidden="true">'));
-                            return;
-                        }
                         if (attachments[i].content_type.indexOf('text') > -1) {
                             if (attachments[i].content !== null) {
-                                if (attachments[i].content.indexOf('----BEGIN PGP') > 0) {
-                                    this.append($('<i class="' + lockclass + '" aria-hidden="true">'));
+                                if (attachments[i].content.indexOf('----BEGIN PGP MESSAGE') > 0) { // Search for PGP Inline and draw lock
+                                    this.append($('<i class="' + newlockclass + '" aria-hidden="true">'));
                                     extensions.paperClip.call(this, baton);
                                     return;
                                 }
@@ -110,7 +109,7 @@ define('oxguard/mail/maillist', ['io.ox/mail/common-extensions', 'io.ox/core/ext
                 baton.data.og = true;
                 baton.model.set('og', true);
                 this.append($('<i class="' + lockclass + '" aria-hidden="true">'));
-                
+
                 if (attachments === undefined) {
                     return;
                 }
@@ -131,24 +130,13 @@ define('oxguard/mail/maillist', ['io.ox/mail/common-extensions', 'io.ox/core/ext
             console.log('Problem checking list for OG email');
             console.log(ex);
         }
-
     }
-    
-    
+
     ext.point('io.ox/mail/detail/header').extend({
         id: 'OGHpaper-clip',
         after: 'flag-picker',
         draw: function (baton) {
             if (baton.data.decoded === true) {
-       //         var lockicon = $('<i class="' + lockclass + '" aria-hidden="true" title="' + gt('This Email was secured with Guard and has been decrypted.') + '"/>');
-       //         lockicon.click(function () {
-       //             require(['oxguard/mail/register_mail', 'io.ox/core/api/account'], function (mail, account) {
-        //                if (_.contains(account.getFoldersByType('sent'), baton.data.folder_id)) {
-         //                   mail.status(baton);
-         //               }
-         //           });
-         //       });
-         //       this.append(lockicon);
                 if (baton.data.attachments === undefined) return;
                 if (baton.data.attachments.length > 1) {// If we do have more than one attachment, add icon
                     extensions.paperClip.call(this, baton);
@@ -156,8 +144,6 @@ define('oxguard/mail/maillist', ['io.ox/mail/common-extensions', 'io.ox/core/ext
             } else extensions.paperClip.call(this, baton);
         }
     });
-    
-    ext.point('io.ox/mail/detail/header').disable('paper-clip');
- 
 
+    ext.point('io.ox/mail/detail/header').disable('paper-clip');
 });
