@@ -7,20 +7,18 @@
  *
  * Copyright (C) Open-Xchange Inc., 2006-2011
  */
-define('oxguard/mail/oxguard_mail', ['io.ox/core/extensions',
-                                     'oxguard/oxguard_core', 'oxguard/core/og_http',
-                              'gettext!oxguard/mail/oxguard_mail'],
-                              function (ext, oxguard, http, gt) {
+define('oxguard/mail/oxguard_mail', [
+    'io.ox/core/extensions',
+    'oxguard/oxguard_core',
+    'oxguard/core/og_http',
+    'gettext!oxguard'
+], function (ext, oxguard, http, gt) {
     'use strict';
-    
+
     var encrPrivKey = '';
 
-    
-    
     ////////////////////////   RECEIVE / READ
-    
 
-    
     function loadKeyClick(evt) {
         var file = evt.target.files[0];
         var reader = new FileReader();
@@ -31,8 +29,7 @@ define('oxguard/mail/oxguard_mail', ['io.ox/core/extensions',
         };
         reader.readAsText(file);
     }
-    
-    
+
     function localDecode(baton, auth, password, extrapass, location) {
 
         require(['oxguard/crypto/encr', 'oxguard/crypto/jsencrypt'], function (encr, JS) {
@@ -45,7 +42,6 @@ define('oxguard/mail/oxguard_mail', ['io.ox/core/extensions',
                     notifications.yell('error', gt('Bad private key'));
                 });
                 $('#busygif').hide();
-                
             } else {
                 var id = baton.data.headers['X-OxGuard-ID'];
                 var params = '&itemid=' + id + '&userid=' + ox.user_id + '&cid=' + ox.context_id +
@@ -65,10 +61,9 @@ define('oxguard/mail/oxguard_mail', ['io.ox/core/extensions',
                                 window.oxguarddata.priv = undefined;
                             }, time);
                         }
-                        require (['oxguard/mail/getmail'], function (reader) {
+                        require (['oxguard/mail/proprietary/getmail'], function (reader) {
                             reader.getMail(baton, '', '', extrapass, location, decodedKey);// Get the mail
                         });
-                        
                     } catch (e)
                     {
                         console.log(e);
@@ -79,29 +74,26 @@ define('oxguard/mail/oxguard_mail', ['io.ox/core/extensions',
                     require (['io.ox/core/notifications'], function (notifications) {
                         notifications.yell('error', gt('Failed to decrypt'));
                     });
-
                 });
             }
         });
-
     }
-    
+
     // Unified inbox combines folder and email ID, returns email id
     function getId(baton) {
+        try {
+            var view = baton.view.cid;
+            return (view);
+        } catch (e) {
+        }
         var id = decodeURIComponent(baton.data.id);
         try {
             id = id.substring(id.lastIndexOf('/') + 1);
-        } catch (e)
-            {
-            }
+        } catch (e) {}
         return (id);
     }
-    
 
-    
-    function passwordPrompt(baton, badpass, location, goFunction)
-
-    {
+    function passwordPrompt(baton, badpass, location, goFunction) {
         var id = getId(baton);
         var grdPasswordPrompt = $('<div class="alert" style="width:80%;"/>');
         var mainpassprompt = $('<span style="font-weight:bold;">' + gt('Secure Email, enter your Guard security password') + '</span><div style="height:10px;"/>');
@@ -126,7 +118,7 @@ define('oxguard/mail/oxguard_mail', ['io.ox/core/extensions',
             $('[name="rememberpass' + id + '"]').click();
         });
         //#. Extra passwords can be added to emails for added security.  This is the prompt for it
-        var extrapass = $('<span><p style="padding-top:10px;">' + gt('This email was sent with an extra password.') + '<br/>' + 
+        var extrapass = $('<span><p style="padding-top:10px;">' + gt('This email was sent with an extra password.') + '<br/>' +
                 //#. Please enter the extra password in the box below
                 gt('Please enter below') + ':</p> </span>');
         var extrapassbox = $('<input type="password" id="extrapass' + id + '"/>');
@@ -152,14 +144,14 @@ define('oxguard/mail/oxguard_mail', ['io.ox/core/extensions',
         });
         passwordbox.keypress(function (e) {
             if (e.which === 13) {
-               // passButton.click();
+                // passButton.click();
                 go();
             }
         });
         extrapassbox.keypress(function (e) {
             if (e.which === 13) {
-                go();            
-               // passButton.click();
+                go();
+                // passButton.click();
             }
         });
         var mainprompt = (window.oxguarddata.passcode === null) || badpass || (window.oxguarddata.passcode === 'NoPrivate');
@@ -168,13 +160,17 @@ define('oxguard/mail/oxguard_mail', ['io.ox/core/extensions',
         if (extraprompt && mainprompt) {
             grdPasswordPrompt.append(mainpassprompt).append(passwordbox).append(placeholder).append(rememberpass).append(extrapass).append(extrapassbox).append(passButton).append(cont);
             window.setTimeout(function () {
-                passwordbox.focus();
+                if (!_.device('ios')) {
+                    passwordbox.focus();
+                }
             }, 1);
         }
         if (!extraprompt && mainprompt) {
             grdPasswordPrompt.append(mainpassprompt).append(passwordbox).append(passButton).append(placeholder).append(rememberpass).append(cont);
             window.setTimeout(function () {
-                passwordbox.focus();
+                if (!_.device('ios')) {
+                    passwordbox.focus();
+                }
             }, 1);
         }
         if (extraprompt && !mainprompt) {
@@ -183,7 +179,7 @@ define('oxguard/mail/oxguard_mail', ['io.ox/core/extensions',
                 extrapassbox.focus();
             }, 1);
         }
-        
+
         function go() {
             $('#error' + id).show();
             var password = ($('#oxgrpass' + id).val() === undefined) ? '' : $('#oxgrpass' + id).val();
@@ -193,63 +189,43 @@ define('oxguard/mail/oxguard_mail', ['io.ox/core/extensions',
                 localDecode(baton, auth, password, extrapass, location);
                 return;
             }
-            require (['oxguard/mail/getmail'], function (reader) {
-                if (auth === null) {// if no main password, send for auth/temp check
-                    if ($('input[name="rememberpass' + id + '"]').is(':checked')) {
-                        oxguard.auth(ox.user_id, $('#oxgrpass' + id).val())
-                        .done(function (data) {
-                            if (data.auth.length > 20) {
-                                $('.og_signout').show();
-                                window.oxguarddata.passcode = data.auth;
-                                if (goFunction !== undefined) {
-                                    goFunction (id);
-                                } else
-                                    reader.getMail(baton, window.oxguarddata.passcode, '', extrapass, location);
-                                var time = $('#duration' + id).val() * 1000 * 60;
-                                window.setTimeout(function () {
-                                    window.oxguarddata.passcode = null;
-                                    $('.og_signout').hide();
-                                }, time);
-                            } else {
-                                $('#busygif').hide();
-                                require (['io.ox/core/notifications'], function (notifications) {
-                                    
-                                    if (data.auth.indexOf('Lockout') > -1) {
-                                        notifications.yell('error', gt('Temporary Lockout'));
-                                    } else {
-                                        //#. Bad, incorrect password
-                                        notifications.yell('error', gt('Bad password'));
-                                    }
-                                });
-                            }
-                        });
-                    } else {
-                        if (goFunction !== undefined) {
+            if (auth === null) {// if no main password, send for auth/temp check
+                if ($('input[name="rememberpass' + id + '"]').is(':checked')) {
+                    oxguard.auth(ox.user_id, $('#oxgrpass' + id).val())
+                    .done(function (data) {
+                        if (data.auth.length > 20) {
+                            $('.og_signout').show();
+                            window.oxguarddata.passcode = data.auth;
                             goFunction (id);
-                        } else 
-                            reader.getMail(baton, auth, password, extrapass, location);
-                    }
+                            var time = $('#duration' + id).val() * 1000 * 60;
+                            window.setTimeout(function () {
+                                window.oxguarddata.passcode = null;
+                                $('.og_signout').hide();
+                            }, time);
+                        } else {
+                            $('#busygif').hide();
+                            require (['io.ox/core/notifications'], function (notifications) {
+                                if (data.auth.indexOf('Lockout') > -1) {
+                                    notifications.yell('error', gt('Temporary Lockout'));
+                                } else {
+                                    //#. Bad, incorrect password
+                                    notifications.yell('error', gt('Bad password'));
+                                }
+                            });
+                        }
+                    });
                 } else {
-                    if (goFunction !== undefined) {
-                        goFunction (id);
-                    } else
-                        reader.getMail(baton, auth, password, extrapass, location);
+                    goFunction (id);
                 }
-            });
+            } else {
+                goFunction (id);
+            }
         }
-        
         var contdiv = $('<div class="content" id = "content' + id + '"/>').append(grdPasswordPrompt);
         return (contdiv);
     }
-    
-   
-    
-    return {
 
-        passwordPrompt : passwordPrompt
-            
+    return {
+        passwordPrompt: passwordPrompt
     };
-    
-    
-    
 });
