@@ -6,12 +6,13 @@
  *
  * Copyright (C) Open-Xchange Inc., 2006-2011
  */
-define('oxguard/mail/upsell', ['oxguard/core/og_http'],
-                           function (http) {
+define('oxguard/mail/upsell', [
+    'oxguard/core/og_http'
+], function (http) {
     'use strict';
-    
+
     var adding = false;
-    
+
     // Add upsell message to header of email
     function upsell(location) {
         var params = '&cid=' + ox.context_id + '&id=' + ox.user_id + '&lang=' + ox.language;
@@ -22,13 +23,12 @@ define('oxguard/mail/upsell', ['oxguard/core/og_http'],
             var upsellDiv = $('<div class="guardUpsell"></div>').append(data);
             location.find('.detail-view-header').after(upsellDiv);
         })
-        .always(function() {
+        .always(function () {
             adding = false;
         });
     }
-    
+
     return {
-        upsell : upsell
+        upsell: upsell
     };
-    
-});
\ No newline at end of file
+});
