@@ -10,52 +10,258 @@
 define('oxguard/oxguard_core', [
     'settings!io.ox/mail',
     'oxguard/core/og_http',
-    'gettext!oxguard/oxguard_core'
+    'gettext!oxguard'
 ], function (settings, og_http, gt) {
     'use strict';
-    
+
+    var CreateKeysViewModel = Backbone.Model.extend({
+        initialize: function () {
+            //FIXME: reduce callback hell a little
+            if (window.oxguarddata.username === undefined) {
+                require(['io.ox/core/api/user']).done(function (user) {
+                    window.oxguarddata.username = user.getName().done(function (data) {
+                        window.oxguarddata.username = data;
+                    });
+                });
+            }
+        },
+        defaults: {
+            email: '',
+            initialSetup: false,
+            sent: false
+        },
+        toJSON: function () {
+            var userdata = {
+                user_id: ox.user_id,
+                sessionID: ox.session,
+                language: ox.language,
+                cid: ox.context_id
+            };
+
+            if (window.oxguarddata.username !== undefined) userdata.name = window.oxguarddata.username;
+
+            return _.extend(userdata, this.pick('email', 'password'));
+        },
+        send: function () {
+            var self = this;
+            this.trigger('before:send');
+            if (!this.isValid()) {
+                this.trigger('send send:error', this.validationError);
+                return;
+            }
+            og_http.post(ox.apiRoot + '/oxguard/login?action=create', '&session=' + ox.session + (this.get('initialSetup') ? '' : '&add=true'), this.toJSON())
+            .done(function (data) {
+                if (data.indexOf('ok') > 0) {
+                    window.oxguarddata.passcode = null;
+                    self.trigger('send send:ok');
+                    self.set('sent', true);
+                } else {
+                    self.trigger('send send:error', gt('Problems creating keys, please try again later'));
+                }
+            })
+            .fail(function (data) {
+                var error;
+                if (data.responseText.trim() === 'Existing') {
+                    error = gt('Problems creating keys.  Keys already exist for this email address in another account');
+                } else {
+                    error = gt('Problems creating keys, please try again later');
+                }
+                self.trigger('send send:error', error);
+            });
+        },
+        validate: function (attrs) {
+            var errors = [];
+            var minlen = window.oxguarddata.settings.min_password_length;
+            if (minlen !== undefined && attrs.password !== undefined && attrs.password.length < minlen) {
+                errors.push({
+                    field: '.password',
+                    message: gt('Passwords must be at least %s characters in length', minlen)
+                });
+            }
+            if (attrs.password !== attrs.passwordValidation) {
+                errors.push({
+                    field: '.password-validation',
+                    message: gt('Passwords not equal')
+                });
+            }
+            if ((attrs.email.length > 1) && (!validateEmail(attrs.email))) {
+                errors.push({
+                    field: '.email',
+                    message: gt('Enter new secondary Email address')
+                });
+            }
+            return errors.length === 0 ? undefined : errors;
+        },
+        //handle password strength warnings (those not catched by validate) - adopted from oxquard/core/passwords.passwordCheck
+        checkStrength: function () {
+            var min = window.oxguarddata.settings.min_password_length;
+            var len = window.oxguarddata.settings.password_length;
+            if (min === undefined) min = 6;
+            if (len === undefined) len = 10;
+
+            if (len <= min) len = min + 1;
+            if (!this.get('password')) return;
+
+            if (this.get('password').length < min) {
+                this.set('passwordStrength', 'bad');
+                return;
+            }
+
+            var regex = /(?=^.{8,}$)(?=.*\d)(?=.*[!@#$%^&*]+)(?![.\n])(?=.*[A-Z])(?=.*[a-z]).*$/;
+            if (this.get('password').match(regex)) {
+                this.set('passwordStrength', 'good');
+                return;
+            }
+
+            this.set('passwordStrength', 'weak');
+        }
+    });
+
+    var CreateKeysView = Backbone.View.extend({
+        className: 'guard-create-key form-horizontal',
+        initialize: function () {
+            if (!this.model) this.model = new CreateKeysViewModel();
+            this.listenTo(this.model, 'change', this.handleChange);
+            this.listenTo(this.model, 'before:send', this.busy);
+            this.listenTo(this.model, 'send', this.idle);
+
+            this.$wait = $('<div class="og_wait" id="keygen">').append(
+                $('<i class="fa-key fa icon-key fa-spin icon-spin"/>'),
+                $('<span>').text(gt('Generating key, Please wait'))
+            ).hide();
+        },
+
+        events: {
+            'keyup input[name=newogpassword]': 'onPasswordChange',
+            'keyup input[name=newogpassword2]': 'onPasswordValidationChange',
+            'change input[name=recoverymail]': 'onRecoverymailChange'
+        },
+        onPasswordChange: function (ev) {
+            this.model.set('password', ev.target.value);
+        },
+        onPasswordValidationChange: function (ev) {
+            this.model.set('passwordValidation', ev.target.value);
+        },
+        onRecoverymailChange: function (ev) {
+            this.model.set('email', ev.target.value);
+        },
+
+        handleChange: function (model) {
+            var $el = this.$el;
+            //reset error fields
+            $el.find('.has-error')
+                .removeClass('has-error')
+                .find('.error-msg').empty();
+
+            if (!model.isValid()) {
+                model.validationError.forEach(function (error) {
+                    $el.find(error.field)
+                        .addClass('has-error')
+                        .find('.error-msg').text(error.message);
+                });
+            }
+            model.checkStrength();
+            var strength = model.get('passwordStrength');
+            $el.find('.password')
+                .toggleClass('has-success', strength === 'good')
+                .toggleClass('has-warning', strength === 'weak');
+        },
+
+        busy: function () {
+            this.$wait.show();
+        },
+        idle: function () {
+            this.$wait.hide();
+        },
+
+        renderDescription: function (el) {
+            el.append($('<div>').append(
+                this.model.get('initialSetup') ? $('<p>').text(gt('This appears to be the first time you have used Encryption')) : '',
+                $('<p>').text(gt('Please enter a password to protect your new encrypted items'))
+            ));
+            return this;
+        },
+        renderPasswordPrompt: function (el) {
+            el.append(
+                $('<div>').addClass('form-group password').append(
+                    $('<label>')
+                        .addClass('col-sm-12 col-md-4 control-label')
+                        .text(gt('Password')),
+                    $('<div>').addClass('col-sm-12 col-md-8').append(
+                        $('<input name="newogpassword" type="password"/>').addClass('form-control')
+                    ),
+                    $('<div>').addClass('col-sm-12 error-msg')
+                ),
+                $('<div>').addClass('form-group password-validation').append(
+                    $('<label>')
+                        .addClass('col-sm-12 col-md-4 control-label')
+                        .text(gt('Confirm')),
+                    $('<div>').addClass('col-sm-12 col-md-8').append(
+                        $('<input name="newogpassword2" type="password"/>').addClass('form-control')
+                    ),
+                    $('<div>').addClass('col-sm-12 error-msg')
+                )
+            );
+            return this;
+        },
+        renderRecoverMailPrompt: function (el) {
+            if (window.oxguarddata.settings.noRecovery === true) return this;  // If no recovery set, don't add prompt for second password
+            if (this.model.get('initialSetup')) {
+                el.append(
+                    $('<hr style="padding:10px;"/>'),
+                    $('<p>').text(gt('Please enter a secondary email address in case you need to reset your password')),
+                        $('<div>').addClass('form-group email').append(
+                        $('<label>').addClass('col-sm-12 col-md-4 control-label').text(gt('Email:')),
+                        $('<div>').addClass('col-sm-12 col-md-8').append(
+                            $('<input name="recoverymail">').addClass('form-control')
+                        ),
+                        $('<div>').addClass('col-sm-12 error-msg')
+                    )
+                );
+            }
+            return this;
+        },
+        render: function () {
+            this.$el.empty().append(this.$wait);
+            return this
+                .renderDescription(this.$el)
+                .renderPasswordPrompt(this.$el)
+                .renderRecoverMailPrompt(this.$el);
+        }
+    });
+
     // Add lock to the message detail view and menu options
     var badCount = 0;
-    
-    // Prompt for creating master keys for this user if not yet created.
-    function createKeys(errors, view, add) {
+
+    function createKeysWizard(guardOnly) {
         var def = $.Deferred();
+        require(['io.ox/core/tk/wizard', 'oxguard/tour/main'], function (Tour) {
+            if (guardOnly) {
+                Tour.registry.get('default/oxguard/createKeys').get('run')().then(def.resolve, def.reject);
+            } else {
+                Tour.registry.get('default/oxguard/choice').get('run')().then(def.resolve, def.reject);
+            }
+        });
+        return def;
+    }
+
+    /**
+     * @returns deferred object resolves to one of:
+     *  * "OK" - everything is fine
+     *  * "cancel" - user cancelled the dialog
+     *  * object - failed with error message stored in responseText attribute
+     */
+    // Prompt for creating master keys for this user if not yet created.
+    function createKeys() {
+        var def = $.Deferred(),
+            view = new CreateKeysView();
+
         require (['io.ox/core/notifications', 'io.ox/core/tk/dialogs'], function (notify, dialogs) {
 
-            var dialog = new dialogs.CreateDialog({ width: 450, center: true, enter: 'ok' });
+            var dialog = new dialogs.CreateDialog({ width: 450, center: true, enter: 'ok', async: true });
             dialog.header($('<h4>').text(gt('Create Guard Security Keys')));
-            var explain = $('<div><p>' + (add === undefined ? (gt('This appears to be the first time you have used Encryption') + '</p><p>') : '') + gt('Please enter a password to protect your new encrypted items') + '</p>');
-            
-            var passdiv = $('<div>').addClass('row-fluid');
-            var newpass1 = $('<input name="newogpassword" type="password"/>');
-            var td1 = $('<td>').append(newpass1);
-            var newpass2 = $('<input name="newogpassword2" type="password"/>');
-            var td2 = $('<td>').append(newpass2);
-            var hint = $('<td>');
-            var table = $('<table class="og_password_prompt"/>')
-            .append($('<tr><td class="pw"><em>' + gt('Password') + ':</em></td></tr>').append(td1).append(hint))
-            .append($('<tr><td class="pw"><em>' + gt('Confirm') + ':</em></td></tr>').append(td2).append('<td></td>'));
-            passdiv.append(table);
-            require (['oxguard/core/passwords'], function (pass) {
-                pass.passwordCheck(newpass1, hint);
-                pass.passwordCompare(newpass2, newpass1);
-            });
-            dialog.getBody().append(explain).append(passdiv);
-            
-            if (add === undefined) {  // If we are not adding an extra key, then prompt for recovery email address
-                var rule = $('<hr style="padding:10px;"/>');
-                var recovery = $('<p>' + gt('Please enter a secondary email address in case you need to reset your password' + '</p>'));
-                var table2 = $('<table class="og_password_prompt"/>');
-                var row = $('<tr><td class="pw"><em>' + gt ('Email:') + '</em></td><td><input name="recoveryemail"/></td></tr>');
-                table2.append(row);
-                dialog.getBody().append(rule).append(recovery).append(table2);
-            }
-            
-            
+            dialog.getBody().append(view.render().$el);
 
-            if (errors !== undefined) {
-                dialog.getBody().append('<div><span style="color: red;">' + errors + '</span></div>');
-            }
             dialog
             .addPrimaryButton('ok', gt('OK'), 'ok')
             .addButton('cancel', gt('Cancel'), 'cancel')
@@ -63,104 +269,51 @@ define('oxguard/oxguard_core', [
                 def.reject('cancel');
             })
             .on('ok', function () {
-                var pass1 = $('input[name="newogpassword"]').val();
-                var pass2 = $('input[name="newogpassword2"]').val();
-                if (pass1 !== pass2) {
-                    createKeys(gt('Passwords not equal'), view, add);
-                    return;
-                }
-                var minlen = window.oxguarddata.settings.min_password_length;
-                if (minlen !== undefined) {
-                    if (pass1.length < minlen) {
-                        createKeys(gt('Passwords must be at least %s characters in length', minlen), view, add);
+                view.model.once('send', function (error) {
+                    if (error) {
+                        def.reject({
+                            responseText: error
+                        });
                         return;
                     }
-                }
-                var emailaddr = $('input[name="recoveryemail"]').val();
-                if (emailaddr === undefined) {
-                    emailaddr = '';
-                }
-                if ((emailaddr.length > 1) && (!validateEmail(emailaddr))) {
-                    createKeys(gt('Enter new secondary Email address'), view, add);
-                    return;
-                }
-                var userdata = {
-                        user_id : ox.user_id,
-                        password : pass1,
-                        sessionID : ox.session,
-                        language : ox.language,
-                        cid : ox.context_id,
-                        email : emailaddr
-                    };
-                if (window.oxguarddata.username !== undefined) userdata.name = window.oxguarddata.username;
-                var waitdiv = $('<div class="og_wait" id="keygen"></div');
-                waitdiv.append('<i class="fa-key fa icon-key fa-spin icon-spin"/><span>' + gt('Generating key, Please wait') + '</span>');
-                $('.window-container-center').append(waitdiv);
-                waitdiv.show();
-                og_http.post(ox.apiRoot + '/oxguard/login?action=create', '&session=' + ox.session + (add !== undefined ? '&add=true' : ''), userdata)
-                .done(function (data) {
-                    $('.og_wait').hide();
-                    if (data.indexOf('ok') > 0) {
-                        window.oxguarddata.passcode = null;
-                        def.resolve('OK');
-                    } else {
-                        $('.og_wait').hide();
-                        notify.yell('error', gt('Problems creating keys, please try again later'));
-                        def.reject('error');
-                    }
-                    
-                })
-                .fail(function (data) {
-                    $('.og_wait').hide();
-                    if (data.responseText.trim() === 'Existing') {
-                        notify.yell('error', gt('Problems creating keys.  Keys already exist for this email address in another account'));
-                    } else
-                    notify.yell('error', gt('Problems creating keys, please try again later'));
-                    def.reject('error');
+                    def.resolve('OK');
                 });
-                
+                view.model.send();
             })
-
             .show(function () {  // Normalize the two tables to have same column size
-                $('input[name="newogpassword"]').focus();
-                window.setTimeout(function () {
-                    var j = 0;
-                    $('.pw').each(function(i,v) { 
-                        var w = $(v).width();
-                        if (w > j) j = w;
-                        });
-                    $('.pw').each(function(i,v) {
-                        $(v).width(j);
-                    });
-                    var email = $('input[name="recoveryemail"]'); // Watch email entry for valid
-                    email.on('keyup', function () {
-                        if (validateEmail(email.val())) {
-                            email.css('background-color', 'white');
-                        } else {
-                            email.css('background-color', 'rgb(253, 187, 179)');
-                        }
-                    });
-                },0);
-                if (window.oxguarddata.username === undefined) {
-                    require(['io.ox/core/api/user']).done(function (api) { 
-                        api.getCurrentUser().done (function (userdata) {
-                            window.oxguarddata.username = userdata.attributes.display_name;
-                        });
-                    });
+                if (!_.device('ios')) {
+                    $('input[name="newogpassword"]').focus();
                 }
             });
+            view.model.on('change', function (model) {
+                var el = dialog.getFooter().find('button[data-action=ok]');
+                if (model.isValid()) {
+                    el.removeAttr('disabled');
+                } else {
+                    el.attr('disabled', true);
+                }
+            });
+            def.always(function () {
+                view.remove();
+                view.model.off();
+                view.model = null;
+                view = null;
+                dialog.close();
+            });
         });
-        return (def);
+        return def;
     }
-    
+
     /// First time OG users or has had password reset
+    /// This is referred to for Guard proprietary check
+    /// Can likely be removed in near future
     function createOxGuardPasswordPrompt(baton, errors, oldpass, goFunction)
     {
         require (['io.ox/core/tk/dialogs'], function (dialogs) {
             var dialog = new dialogs.ModalDialog({ width: 450, center: true, enter: 'okpass' });
             dialog.header($('<h4>').text(gt('First Guard Security Password Use')));
             var explain = $('<div><p>' + gt('Please change the temporary Guard security password that was sent to you in a seperate email.') + '</p></div>');
-            
+
             var passdiv = $('<div>').addClass('row-fluid');
             var newogpassword = $('<input name="newogpassword" type="password"/>');
             var td1 = $('<td>').append(newogpassword);
@@ -176,7 +329,7 @@ define('oxguard/oxguard_core', [
             dialog.getBody().append(explain).append(passdiv);
             require (['oxguard/core/passwords'], function (pass) {
                 pass.passwordCheck(newogpassword, hint);
-                pass.passwordCompare(newogpassword2, newogpassword);
+                pass.passwordCompare(newogpassword2, newogpassword, hint);
             });
             var rule = $('<hr style="padding:10px;"/>');
             var recovery = $('<p>' + gt('Please enter a secondary email address in case you need to reset your password' + '</p>'));
@@ -203,19 +356,19 @@ define('oxguard/oxguard_core', [
                     return;
                 }
                 var userdata = {
-                        newpass : pass1,
-                        oldpass : oldpass,
-                        email: emailaddr,
-                        user_id : ox.user_id,
-                        sessionID : ox.session,
-                        cid : ox.context_id
-                    };
+                    newpass: pass1,
+                    oldpass: oldpass,
+                    email: emailaddr,
+                    user_id: ox.user_id,
+                    sessionID: ox.session,
+                    cid: ox.context_id
+                };
                 if ((emailaddr.length > 1) && (!validateEmail(emailaddr))) {
                     createOxGuardPasswordPrompt(baton, gt('Enter new secondary Email address'), oldpass, goFunction);
                     return;
                 }
                 if (validateEmail(emailaddr)) userdata.email = emailaddr;
-                require (['io.ox/core/notifications', 'oxguard/mail/oxguard_mail', 'oxguard/mail/getmail', 'oxguard/core/og_http'], function (notifications, oxmail, reader, og_http) {
+                require (['io.ox/core/notifications', 'oxguard/mail/oxguard_mail', 'oxguard/core/og_http'], function (notifications, oxmail, og_http) {
                     og_http.post(ox.apiRoot + '/oxguard/login?action=changepass', '&session=' + ox.session, userdata)
                     .done(function (data) {
                         if (typeof data === 'string') data = $.parseJSON(data);
@@ -224,7 +377,7 @@ define('oxguard/oxguard_core', [
                             $('input[name="newogpassword"]').val('');
                             $('input[name="newogpassword2"]').val('');
                             window.oxguarddata.passcode = null;
-                            goFunction (baton, data);
+                            if (goFunction !== undefined) goFunction (baton, data);
                             notifications.yell('success', gt('Password changed successfully'));
                         } else {
                             if (data.auth === 'Bad new password') {
@@ -242,7 +395,6 @@ define('oxguard/oxguard_core', [
                             }
                             notifications.yell('error', gt('Failed to change password'));
                         }
-                    
                     })
                     .fail(function () {
                         notifications.yell('error', gt('Failed to change password'));
@@ -252,16 +404,20 @@ define('oxguard/oxguard_core', [
             .show(function () {
                 if (oldpass !== undefined) {
                     $('input[name="oldogpassword"]').val(oldpass);
-                    $('input[name="newogpassword"]').focus();
+                    if (!_.device('ios')) {
+                        $('input[name="newogpassword"]').focus();
+                    }
                 } else
-                    $('input[name="oldogpassword"]').focus();
+                    if (!_.device('ios')) {
+                        $('input[name="oldogpassword"]').focus();
+                    }
                 window.setTimeout(function () {
                     var j = 0;
-                    $('.pw').each(function(i,v) { 
+                    $('.pw').each(function (i,v) {
                         var w = $(v).width();
                         if (w > j) j = w;
-                        });
-                    $('.pw').each(function(i,v) {
+                    });
+                    $('.pw').each(function (i,v) {
                         $(v).width(j);
                     });
                     var email = $('input[name="recoveryemail"]'); // Watch email entry for valid
@@ -276,22 +432,20 @@ define('oxguard/oxguard_core', [
             });
         });
     }
-    
-    function validateEmail(email) { 
+
+    function validateEmail(email) {
         var re = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
         return re.test(email);
-    } 
-    
+    }
+
     function getId(baton) {
         var id = decodeURIComponent(baton.data.id);
         try {
             id = id.substring(id.lastIndexOf('/') + 1);
-        } catch (e)
-            {
-            }
+        } catch (e) {}
         return (id);
     }
-    
+
     function handleFailEmail (data, baton, deferred, goFunction) {
         baton.view.loaded = true;
         window.oxguarddata.priv = undefined;
@@ -322,6 +476,9 @@ define('oxguard/oxguard_core', [
                 break;
             case 'Bad Password':
                 errorMessage = gt('Unable to decrypt Email, incorrect password.');
+                require (['io.ox/core/notifications'], function (notifications) {
+                    notifications.yell('error', gt('Bad password'));
+                });
                 badCount++;
                 if (badCount > 2) {
                     var url = document.URL;
@@ -337,6 +494,10 @@ define('oxguard/oxguard_core', [
                 errorMessage = gt('Your account is locked out for %s minutes', resp[1]);
                 retry = false;
                 break;
+            case 'Error':
+                errorMessage = gt('Error');
+                retry = false;
+                break;
             default:
                 console.log(resp);
                 errorMessage = gt('Unable to decrypt Email, incorrect password.');
@@ -347,8 +508,8 @@ define('oxguard/oxguard_core', [
             baton.view.$el.find('#error' + eid).replaceWith('<div class="error" id="error' + eid + '"><br>' + errorMessage + '</hr></div>');
             if (badCount > 2) {
                 baton.view.$el.find('#guardsettings').click(function (e) {
-                    ox.launch('io.ox/settings/main', {id:'oxguard'}).done(function () {
-                         this.setSettingsPane({id: 'oxguard'}); 
+                    ox.launch('io.ox/settings/main', { id: 'oxguard' }).done(function () {
+                        this.setSettingsPane({ id: 'oxguard' });
                     });
                     e.preventDefault();
                 });
@@ -364,12 +525,10 @@ define('oxguard/oxguard_core', [
         }
         try {// blank out auth if present
             if (window.oxguarddata.passcode.length > 20) window.oxguarddata.passcode = null;
-        } catch (ex) {
-            
-        }
+        } catch (ex) {}
         deferred.reject('error');
     }
-    
+
     function getpassword (message) {
         var def = $.Deferred();
         require (['io.ox/core/tk/dialogs'], function (dialogs) {
@@ -399,22 +558,21 @@ define('oxguard/oxguard_core', [
     }
 
     return {
-        
-            // Send authorization to the oxguard server
+        // Send authorization to the oxguard server
         auth: function authorize(userid, password, extra, keyid)
             {
             var def = $.Deferred();
             var defaultSendAddress = $.trim(settings.get('defaultSendAddress', ''));
             var userdata = {
-                    user_id : userid,
-                    ox_password : password,
-                    encr_password : '',
-                    sessionID : ox.session,
-                    lang: ox.language,
-                    cid : ox.context_id,
-                    email : defaultSendAddress,
-                    extrapass : extra ? extra : ''
-                };
+                user_id: userid,
+                ox_password: password,
+                encr_password: '',
+                sessionID: ox.session,
+                lang: ox.language,
+                cid: ox.context_id,
+                email: defaultSendAddress,
+                extrapass: extra ? extra : ''
+            };
             var url = ox.apiRoot + '/oxguard/login?action=login';
             var params = '&session=' + ox.session + '&time=' + new Date().getTime();
             if (keyid !== undefined) params += '&keyid=' + keyid;
@@ -426,16 +584,15 @@ define('oxguard/oxguard_core', [
                 def.reject();
             });
             return def;
-            
         },
-        
-        createKeys : createKeys,
-        validateEmail : validateEmail,
-        handleFailEmail : handleFailEmail,
-        getPassword : getpassword,
-        createOxGuardPasswordPrompt : createOxGuardPasswordPrompt
+        createKeys: createKeys,
+        createKeysWizard: createKeysWizard,
+        CreateKeysViewModel: CreateKeysViewModel,
+        CreateKeysView: CreateKeysView,
+        validateEmail: validateEmail,
+        handleFailEmail: handleFailEmail,
+        getPassword: getpassword,
+        createOxGuardPasswordPrompt: createOxGuardPasswordPrompt
     };
 });
-    
 
-    
