@@ -7,10 +7,12 @@
  *
  * Copyright (C) Open-Xchange Inc., 2006-2011
  */
-define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/core/og_http',
-                           'css!oxguard/style.css'],
-                           function (gt, http) {
-    
+define('oxguard/pgp/publickeys', [
+    'gettext!oxguard',
+    'oxguard/core/og_http',
+    'less!oxguard/style'
+], function (gt, http) {
+
     var deleting = false;
 
     // Change the status of a key to sharing or not
@@ -32,7 +34,7 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
             fail(data.responseText);
         });
     }
-    
+
     // Change the status of a key to sharing or not
     function changeInline (e) {
         var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id +
@@ -52,25 +54,21 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
             alert ('fail');
         });
     }
-    
-        // General fail call to display error message
+
+    // General fail call to display error message
     function fail (message) {
         require(['io.ox/core/notifications'], function (notify) {
             notify.yell('error', message);
         });
     }
-    
-      function wait () {
+
+    function wait () {
         $('#og_wait').show();
     }
 
-    
-    
     function hideWait () {
         $('#og_wait').hide();
     }
-    
-    
 
     function deleteShare (e) {
         if (deleting) return;
@@ -100,7 +98,7 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
         });
         e.preventDefault();
     }
-    
+
     function updateKeyTable(id, list) {
         var deferred = $.Deferred();
         var date = new Date();
@@ -123,7 +121,7 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
                     var tr = $('<tr>');
                     if (data[i].guard === true || data[i].shared === true) tr.addClass('oxguard_key_share');
                     var td1 = $('<td style="text-align:left;max-width:150px;overflow:hidden;text-overflow:ellipsis;">');
-                    td1.append(data[i].email);
+                    td1.append(data[i].email.replace(/>/gi,'&gt;').replace(/</gi,'&lt;'));
                     tr.append(td1);
                     var td2 = $('<td>');
                     td2.append(data[i].ids);
@@ -137,7 +135,7 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
                         .click (deleteShare);
                         td5.append(del);
                         showDelete = true;
-                    } 
+                    }
                     tr.append(td4).append(td5);
                     newtable.append(tr);
                 }
@@ -160,7 +158,6 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
         });
         return (deferred);
     }
-    
 
     function showDetail (id, guard) {
         var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&ids= ' + id + '&guard=' + guard +
@@ -171,63 +168,23 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
         .done(function (resp) {
             var json = JSON.parse(resp);
             var data = json.data;
-            var keyids = '';
-            var images = null;
-            var keylong = ''; // This will be the key that has the ids (usually master)
             require (['io.ox/core/tk/dialogs'], function (dialogs) {
-                var dialog = new dialogs.CreateDialog({ width: 450, height: 450, center: true,  enter : 'ok'});
+                var dialog = new dialogs.CreateDialog({ width: 450, height: 450, center: true,  enter: 'ok' });
                 dialog.header($('<h4>').text(gt('Key Details')));
-                var resultdiv = $('<div>');
-                for (var i = 0; i < data.length; i++) {
-                    keyids = keyids + data[i].Key + ' ';  // List of key ids for changing share, inline (linked)
-                    if (i > 0) resultdiv.append('<hr>');
-                    var detaildiv = $('<div style="padding-left:20px;">');
-                    //#. if key is "expired"
-                    if (data[i].Expired) detaildiv.append('<b>' + gt('Expired') +'</b><br>');
-                    if (data[i].Revoked) detaildiv.append('<b style="color:red">' + gt('Revoked') +'</b><br>');
-                    //#. Fingeprint of the key
-                    detaildiv.append(gt('Fingerprint:') + ' ' + formatFingerprint(data[i].Fingerprint) + '<br>');
-                    detaildiv.append(gt('Created:') + ' ' + data[i].Created + '<br>');
-                    //#. Key is a Master key
-                    detaildiv.append(gt('Master:') + ' ' + (data[i].Master ? gt('True') : gt('False')) + ',  ');
-                    //#. Key is an encryption key
-                    detaildiv.append(gt('Encryption:') + ' ' + (data[i].Encryption ? gt('True') : gt('False')) + '<br>');
-                    var ids = '';
-                    for (var j = 0; j < data[i].ids.length; j++) {
-                        if (j > 0) ids = ids + ', ';
-                        ids = ids + data[i].ids[j].replace('<', '&lt').replace('>', '&gt');
-                    }
-                    if (ids !== '') {
-                        detaildiv.append(gt('IDs: ') + ids + '<br>');
-                        keylong = data[i].KeyLong;  // The ID of the key with IDs for signature verification
-                    }
-                    if (data[i].images !== undefined) {
-                        if (data[i].images.length > 0) {
-                            images = data[i].images;
-                            var image = $('<img alt="Embedded Image" id="imageID" src="' +  data[i].images[0].data + '" style="float:right;max-height:50px;max-width:50px;"/>');
-                            detaildiv.append(image);
-                        }
-                    }
-                    if (data[i].Expires !== 'never') {
-                        if (data[i].Expires !== undefined)
-                            detaildiv.append(gt('Expires in %1$s days', data[i].Expires) + '<br>');
-                    }
-                    resultdiv.append(detaildiv);
-                }
-                
-                
-                dialog.getBody().append(resultdiv);
+                var keydetail = keyDetail(data);
+                dialog.getBody().append(keydetail.div);
+
                 if ((data.length > 0) && (guard !== 'true')) { // we don't display share options for Guard created keys
                     var optionsdiv = $('<div class="keyoptions">');
                     var sharingtext = $('<label>' + gt('Share Keys') + '</label>');
-                    var sharing = $('<input type="checkbox" value="' + keyids + '" style="margin-right:15px;">');
+                    var sharing = $('<input type="checkbox" value="' + keydetail.keyids + '" style="margin-right:15px;">');
                     sharing.prop('checked', json.share > 0)
                     .on('click', changeShare);
                     sharingtext.click(function () {
                         sharing.click();
                     });
                     var inlinetext = $('<label>' + gt('Use PGP Inline') + '</label>');
-                    var inline = $('<input type="checkbox" value="' + keyids + '" style="margin-right:15px; margin-left:40px;">')
+                    var inline = $('<input type="checkbox" value="' + keydetail.keyids + '" style="margin-right:15px; margin-left:40px;">')
                     .on('click', changeInline);
                     inline.prop('checked', json.inline);
                     inlinetext.click(function () {
@@ -239,16 +196,16 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
                 .addPrimaryButton('ok', gt('OK'), 'ok')
                 .addButton('sigs', gt('Signatures'), 'sigs')
                 .on('sigs', function () {
-                    showSignatures(keylong);
+                    showSignatures(keydetail.keylong);
                 })
                 .show(function () {
                     $('#imageID').click(function () {
-                        if (images !== null) {
+                        if (keydetail.images !== null) {
                             var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&session=' + ox.session;
                             // Send the request to the oxguard server for the encrypted content key to decrypt
                             var url = '/oxguard/pgp?action=getkeyimage';
-                            for (var i = 0; i < images.length; i++) {
-                                var imageParams = params + '&image=' + i + '&keyid=' + images[i].keyid;
+                            for (var i = 0; i < keydetail.images.length; i++) {
+                                var imageParams = params + '&image=' + i + '&keyid=' + keydetail.images[i].keyid;
                                 window.open(ox.apiRoot + url + imageParams);
                             }
                         }
@@ -257,29 +214,70 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
             });
         });
     }
-    
 
-    
- //   function formatKeyID (id) {
- //       if (id.length < 9) return (id);
- //       return ('<span class="keystart">' + id.substring(0,8) + '</span><span class="keyend">' + id.substring(8) + '</span>');
- //   }
-    
+    function keyDetail (data) {
+        var keyids = '';
+        var keylong = ''; // This will be the key that has the ids (usually master)
+        var images = null;
+        var resultdiv = $('<div>');
+        for (var i = 0; i < data.length; i++) {
+            keyids = keyids + data[i].Key + ' ';  // List of key ids for changing share, inline (linked)
+            if (i > 0) resultdiv.append('<hr>');
+            var detaildiv = $('<div style="padding-left:20px;">');
+            //#. if key is "expired"
+            if (data[i].Expired) detaildiv.append('<b>' + gt('Expired') +'</b><br>');
+            if (data[i].Revoked) detaildiv.append('<b style="color:red">' + gt('Revoked') +'</b><br>');
+            //#. Fingeprint of the key
+            detaildiv.append(gt('Fingerprint:') + ' ' + formatFingerprint(data[i].Fingerprint) + '<br>');
+            detaildiv.append(gt('Created:') + ' ' + data[i].Created + '<br>');
+            //#. Key is a Master key
+            detaildiv.append(gt('Master:') + ' ' + (data[i].Master ? gt('True') : gt('False')) + ',  ');
+            //#. Key is an encryption key
+            detaildiv.append(gt('Encryption:') + ' ' + (data[i].Encryption ? gt('True') : gt('False')) + '<br>');
+            var ids = '';
+            for (var j = 0; j < data[i].ids.length; j++) {
+                if (j > 0) ids = ids + ', ';
+                ids = ids + data[i].ids[j].replace(/>/gi,'&gt;').replace(/</gi,'&lt;');
+            }
+            if (ids !== '') {
+                detaildiv.append(gt('IDs: ') + ids + '<br>');
+                keylong = data[i].KeyLong;  // The ID of the key with IDs for signature verification
+            }
+            if (data[i].images !== undefined) {
+                if (data[i].images.length > 0) {
+                    images = data[i].images;
+                    var image = $('<img alt="Embedded Image" id="imageID" src="' +  data[i].images[0].data + '" style="float:right;max-height:50px;max-width:50px;"/>');
+                    detaildiv.append(image);
+                }
+            }
+            if (data[i].Expires !== 'never') {
+                if (data[i].Expires !== undefined)
+                    detaildiv.append(gt('Expires in %1$s days', data[i].Expires) + '<br>');
+            }
+            resultdiv.append(detaildiv);
+        }
+        return {
+            div: resultdiv,
+            keyids: keyids,
+            keylong: keylong,
+            images: images
+        };
+    }
+
     function formatFingerprint (fp) {
         if (fp.length < 28) return (fp);
         var line1 = fp.substring (0,24);
         var line2 = fp.substring (25, fp.length-10) + '<b>' + fp.substring(fp.length-10) + '</b>';
         return ('<span style="float:right;">' + line1 + '</span><br/><span style="float:right">' + line2 + '</span>');
     }
-    
+
     function update(id, list) {
         $('.refreshkeys').addClass('fa-spin');
-        updateKeyTable(id, list).done(function() {
+        updateKeyTable(id, list).done(function () {
             $('.refreshkeys').removeClass('fa-spin');
         });
     }
-    
-  
+
     function showSignatures (id) {
         var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&keyid= ' + id +
         '&session=' + ox.session;
@@ -296,7 +294,7 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
             });
         });
     }
-    
+
     function translate (result) {
         switch (result) {
         case 'Positive':
@@ -318,19 +316,19 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
             //#. In table, the key was "Directly" certified by the signer (verification level)
             return (gt('Direct cert'));
         case 'Revoke':
-          //#. In table, the key was revoked with this signature
+            //#. In table, the key was revoked with this signature
             return (gt('Revocation'));
         case 'Default Cert':
-          //#. In table, the key had "Default certification" by the signer (verification level)
+            //#. In table, the key had "Default certification" by the signer (verification level)
             return (gt('Default Certification'));
         case 'Sub revoke':
-          //#. In table, the key was revoked with this signature
+            //#. In table, the key was revoked with this signature
             return (gt('Revocation'));
         default:
             return (result);
         }
     }
-    
+
     function showSigs (data) {
         var table = $('<table>');
         if (data.length === 0) {
@@ -341,40 +339,39 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
             for (var i = 0; i < data.length; i++) {
                 var tr = $('<tr>');
                 var td1 = $('<td style="text-align:left;max-width:150px;overflow:hidden;text-overflow:ellipsis;">');
-                
+
                 if (data[i].ID === 'image') {
                     if (data[i].image !== undefined) {
                         var image = $('<img alt="Embedded Image" src="' +  data[i].image + '" style="max-height:50px;max-width:50px;"/>');
                         td1.append(image);
                     } else {
-                      //#. Type of object signed was an image
+                        //#. Type of object signed was an image
                         data[i].ID = gt('Image');  // Translate image response
                         td1.append(data[i].ID);
                     }
-                } else 
-                    td1.append ($('<span>' + data[i].ID.replace('<','&lt').replace('>','&gt') + '</span>'));
+                } else {
+                    td1.append ($('<span>' + data[i].ID.replace(/>/gi,'&gt;').replace(/</gi,'&lt;') + '</span>'));
+                }
                 tr.append(td1);
                 var td2 = $('<td>');
                 td2.append (translate(data[i].result));
                 tr.append(td2);
                 var td3 = $('<td>');
-                td3.append (data[i].certifier);
+                td3.append (data[i].certifier.replace(/>/gi,'&gt;').replace(/</gi,'&lt;'));
                 tr.append(td3);
                 table.append(tr);
             }
         }
         require (['io.ox/core/tk/dialogs'], function (dialogs) {
-            var dialog = new dialogs.CreateDialog({ width: 450, center: true,  enter : 'ok'});
+            var dialog = new dialogs.CreateDialog({ width: 450, center: true,  enter: 'ok' });
             dialog.header($('<h4>').text(gt('Key Signatures')));
             dialog.getBody().append($('<div class="oxguard_settings oxguard_signatures">').append(table));
             dialog
-            .addPrimaryButton('ok', gt('OK'), 'ok')
-            .show();
+                .addPrimaryButton('ok', gt('OK'), 'ok')
+                .show();
         });
     }
-    
 
-    
     function listPublic (id, list) {
         if (list === ',,') return;
         var pubdiv = $('<div class="publicKeyDiv"/>');
@@ -382,29 +379,29 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
         if (id == 'settings') tableHeader = $('<b>');
         tableHeader.append(gt('PGP Public Key List'));
         var refresh = $('<a href="#" style="margin-left:10px;"><icon class="fa fa-refresh fa-spin refreshkeys"></a>')
-            .click(function(e) {
+            .click(function (e) {
                 $(this).addClass('fa-spin');
-                updateKeyTable(id, list).done(function() {
+                updateKeyTable(id, list).done(function () {
                     refresh.removeClass('fa-spin');
                 });
                 e.preventDefault();
             });
         var fileinput = $('<input type="file" name="publicKey" style="display:none;" multiple>');
         var addKey = $('<a href="#" style="margin-left:10px;"><icon class="fa fa-plus" id="addpgppublickeys"></a>')
-        .click(function(e) {
+        .click(function (e) {
             fileinput.click();
             fileinput.unbind('change');
             fileinput.on('change', function () {
-               var files = this.files;
-               if (files.length > 0) {
-                   require(['oxguard/pgp/uploadkeys'], function (uploader) {
-                       uploader.upload(files, false, '', '', list)
-                       .done(function () {
-                           updateKeyTable(id, list);
-                           fileinput.val('');
-                       });
-                   });
-               } 
+                var files = this.files;
+                if (files.length > 0) {
+                    require(['oxguard/pgp/uploadkeys'], function (uploader) {
+                        uploader.upload(files, false, '', '', list)
+                        .done(function () {
+                            updateKeyTable(id, list);
+                            fileinput.val('');
+                        });
+                    });
+                }
             });
             e.preventDefault();
         });
@@ -414,12 +411,11 @@ define('oxguard/pgp/publickeys', ['gettext!oxguard/pgp/publickeys', 'oxguard/cor
         pubdiv.append(tableHeader).append(tablediv.append(table));
         update(id, list);
         return (pubdiv);
-        
     }
-    
+
     return {
-        listPublic : listPublic,
-        showSignatures : showSignatures
+        listPublic: listPublic,
+        showSignatures: showSignatures,
+        keyDetail: keyDetail
     };
-    
-});
\ No newline at end of file
+});
