@@ -7,32 +7,30 @@
  *
  * Copyright (C) Open-Xchange Inc., 2006-2011
  */
-define('oxguard/register', ['io.ox/core/extensions', 'oxguard/oxguard_core',
-                           'gettext!oxguard/register', 'css!oxguard/style.css'],
-                           function (ext, oxguard, gt) {
+define('oxguard/register', [
+    'io.ox/core/extensions',
+    'oxguard/oxguard_core',
+    'gettext!oxguard',
+    'settings!oxguard',
+    'less!oxguard/style'
+], function (ext, oxguard, gt, settings) {
     'use strict';
-    
-    
-    var oxguarddata = {
-            passcode : null,
-            settings:  {},
-          //  oldcompose : (ox.version.indexOf('7.6.') > -1),
-            oldcompose: true, // mark oldcompose always true for this version
-            version: '2.0.0-2626'
 
-        };
+    var oxguarddata = {
+        passcode: null,
+        settings:  {},
+        version: '2.2.1-rc3'
+    };
     window.oxguarddata = oxguarddata;
-    
+
     // Login section
     sendauth(''); // initial login, no password yet
-    
-    
-   
-    function sendauth(pass)
-    {
+
+    function sendauth(pass) {
         oxguard.auth(ox.user_id, pass)
         .done(function (data) {
             try {
+                oxguarddata = _.extend(window.oxguarddata, data);
                 if (data.auth.length > 20) {// If good code comes back, then store userid
                     oxguarddata.userid = ox.user_id;
                     oxguarddata.passcode = data.auth;
@@ -43,23 +41,18 @@ define('oxguard/register', ['io.ox/core/extensions', 'oxguard/oxguard_core',
                     } else {
                         oxguarddata.passcode = data.auth;
                     }
+                    if (data.auth !== 'No Key') {
+                        if (settings.get('cryptoProvider') === undefined) {
+                            settings.set('cryptoProvider', 'guard').save();
+                        }
+                    }
                     oxguarddata.userid = -1;
                 }
                 if (ox.context_id === 0) ox.context_id = data.cid; // If the cid wasn't loaded, update from backend
-                oxguarddata.settings = data.settings; // user settings
-                oxguarddata.lang = data.lang;// Languages available
-                oxguarddata.server = data.server;
                 oxguarddata.baton = window.oxguarddata.baton;
-                oxguarddata.pubkey = data.pubKey;
                 oxguarddata.recovery = data.recoveryAvail;
                 window.oxguarddata = oxguarddata;
-                
-                if (window.oxguarddata.baton !== undefined) {
-                    require(['oxguard/register_mail'], function (mail) {
-                        mail.checkOG(window.oxguarddata.baton);
-                    });
-                    window.oxguarddata.baton = undefined;
-                }
+
                 if (sessionStorage !== null) {// If we were passed login info from login screen
                     try {
                         if (sessionStorage.oxguard && (sessionStorage.oxguard !== 'null')) {
@@ -79,7 +72,7 @@ define('oxguard/register', ['io.ox/core/extensions', 'oxguard/oxguard_core',
         })
         .fail(function () {
             $('.og_signout').hide();
-        	console.debug('Unable to connect to the encryption server');
+            console.debug('Unable to connect to the encryption server');
         });
     }
 
@@ -94,10 +87,27 @@ define('oxguard/register', ['io.ox/core/extensions', 'oxguard/oxguard_core',
             .fail(function () {
                 console.log('Fail logout oxguard');
             });
-            
         }
     });
- 
+
+    ext.point('io.ox/core/topbar/right/dropdown').extend({
+        id: 'guard-guided-tour',
+        index: 260,
+        draw: function () {
+            this.append(
+                $('<li class="og_tour">').append(
+                    $('<a href="#" data-action="guard-tour" role="menuitem" tabindex="1">').text(gt('Guided tour for Guard'))
+                )
+                .on('click', function (e) {
+                    e.preventDefault();
+                    require(['io.ox/core/tk/wizard', 'oxguard/tour/main'], function (Tour) {
+                        Tour.registry.run('default/oxguard');
+                    });
+                })
+            );
+        }
+    });
+
     ext.point('io.ox/core/topbar/right/dropdown').extend({
         id: 'logoutOG',
         index: 990,
@@ -114,23 +124,18 @@ define('oxguard/register', ['io.ox/core/extensions', 'oxguard/oxguard_core',
                 })
             );
             var auth = window.oxguarddata.passcode;
-            if (auth === null) {
+            if (auth === null || auth === undefined) {
                 hideLogout();
                 return;
             }
             if (auth.length < 20) hideLogout();
-            
         }
     });
-    
+
     function hideLogout() {
         window.setTimeout(function () {
             $('.og_signout').hide();
         },100);
     }
-    
 
-
-    
- 
 });
