@@ -7,17 +7,18 @@
  *
  * Copyright (C) Open-Xchange Inc., 2006-2011
  */
-define('oxguard/settings', ['io.ox/core/extensions', 'gettext!oxguard/register'],
-                           function (ext, gt) {
+define('oxguard/settings', [
+    'io.ox/core/extensions',
+    'gettext!oxguard'
+], function (ext, gt) {
     'use strict';
 
     // Add settings for encryption to the Settings Page
-    ext.point('io.ox/settings/pane').extend({
-        title: gt('Guard Security Settings'),
-        index: 200,
+    ext.point('io.ox/settings/pane/main').extend({
         id: 'oxguard',
-        advancedMode: false,
-        settingsgroup: 'main'
+        title: gt.pgettext('app', 'Guard Security'),
+        index: 600,
+        loadSettingPane: true
     });
 
-});
\ No newline at end of file
+});
